@@ -1,6 +1,6 @@
 /* xfce4-mpc-plugin.c
  *
- * Copyright (c) 2006-2011 Landry Breuil <landry at rhaalovely.net>
+ * Copyright (c) 2006-2012 Landry Breuil <landry at xfce.org>
  * This code is licensed under a BSD-style license.
  * (OpenBSD variant modeled after the ISC license)
  * All rights reserved.
@@ -43,6 +43,21 @@ mpc_free (XfcePanelPlugin * plugin, t_mpc * mpc)
    g_free (mpc);
 }
 
+#if defined (LIBXFCE4PANEL_CHECK_VERSION) && LIBXFCE4PANEL_CHECK_VERSION (4,9,0)
+static void
+mpc_set_mode (XfcePanelPlugin * plugin, XfcePanelPluginMode mode, t_mpc * mpc)
+{
+   GtkOrientation orientation;
+   DBG ("!");
+
+   orientation =
+      (mode != XFCE_PANEL_PLUGIN_MODE_VERTICAL) ?
+      GTK_ORIENTATION_HORIZONTAL : GTK_ORIENTATION_VERTICAL;
+
+   xfce_hvbox_set_orientation(XFCE_HVBOX(mpc->box), orientation);
+}
+
+#else
 static void
 mpc_set_orientation (XfcePanelPlugin * plugin, GtkOrientation orientation, t_mpc * mpc)
 {
@@ -50,10 +65,15 @@ mpc_set_orientation (XfcePanelPlugin * plugin, GtkOrientation orientation, t_mpc
 
    xfce_hvbox_set_orientation(XFCE_HVBOX(mpc->box), orientation);
 }
+#endif
 
 static gboolean
 mpc_set_size (XfcePanelPlugin * plugin, int size, t_mpc * mpc)
 {
+#if defined (LIBXFCE4PANEL_CHECK_VERSION) && LIBXFCE4PANEL_CHECK_VERSION (4,9,0)
+    size /= xfce_panel_plugin_get_nrows (plugin);
+#endif
+
    DBG ("size=%d",size);
    gtk_container_set_border_width (GTK_CONTAINER (mpc->frame), (size > 26 && mpc->show_frame ? 2 : 0));
 
@@ -746,7 +766,7 @@ static void
 mpc_show_about(XfcePanelPlugin *plugin, t_mpc* mpc)
 {
    GdkPixbuf *icon;
-   const gchar *auth[] = { "Landry Breuil <landry at rhaalovely.net>", NULL };
+   const gchar *auth[] = { "Landry Breuil <landry at xfce.org>", NULL };
    icon = xfce_panel_pixbuf_from_source("applications-multimedia", NULL, 32);
 #if !GTK_CHECK_VERSION (2, 18, 0)
    gtk_about_dialog_set_email_hook (exo_gtk_url_about_dialog_hook, NULL, NULL);
@@ -756,9 +776,10 @@ mpc_show_about(XfcePanelPlugin *plugin, t_mpc* mpc)
       "logo", icon,
       "license", xfce_get_license_text (XFCE_LICENSE_TEXT_BSD),
       "version", PACKAGE_VERSION,
+      "program-name", PACKAGE_NAME,
       "comments", _("A simple panel-plugin client for Music Player Daemon"),
       "website", "http://goodies.xfce.org/projects/panel-plugins/xfce4-mpc-plugin",
-      "copyright", _("Copyright (c) 2006-2011 Landry Breuil\n"),
+      "copyright", _("Copyright (c) 2006-2012 Landry Breuil\n"),
       "authors", auth, NULL);
 
    if(icon)
@@ -805,7 +826,11 @@ mpc_construct (XfcePanelPlugin * plugin)
    g_signal_connect (plugin, "free-data", G_CALLBACK (mpc_free), mpc);
    g_signal_connect (plugin, "save", G_CALLBACK (mpc_write_config), mpc);
    g_signal_connect (plugin, "size-changed", G_CALLBACK (mpc_set_size), mpc);
+#if defined (LIBXFCE4PANEL_CHECK_VERSION) && LIBXFCE4PANEL_CHECK_VERSION (4,9,0)
+   g_signal_connect (plugin, "mode-changed", G_CALLBACK (mpc_set_mode), mpc);
+#else
    g_signal_connect (plugin, "orientation-changed", G_CALLBACK (mpc_set_orientation), mpc);
+#endif
    /* the configure and about menu items are hidden by default */
    xfce_panel_plugin_menu_show_configure (plugin);
 
@@ -816,5 +841,5 @@ mpc_construct (XfcePanelPlugin * plugin)
 
 
 /* register the plugin */
-XFCE_PANEL_PLUGIN_REGISTER_EXTERNAL (mpc_construct);
+XFCE_PANEL_PLUGIN_REGISTER (mpc_construct);
 
